var __WINDOW_SIZE = [window.width, window.height];

$(document).ready(function () {
    window.resizeTo(1200, 900);
});